using System;
using System.ComponentModel;

using Syncfusion.Diagnostics;
using Syncfusion.Styles;
using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;

namespace WindowsApplication1
{
	/// <summary>
	/// Adds "TheLocked" and "TheFont" custom properties to <see cref="GridStyleInfo"/>
	/// </summary>
	/// <remarks>
	/// <example>
	/// See the following code snippets how to get and set custom properties:
	/// <code lang="C#">
	/// GridControl grid = new GridControl();
	/// GridStyleInfo style = new GridStyleInfo();
	/// 
	/// // using ctor with exising style object and caching the object (both C# and VB)
	/// MyCustomStyleProperties mcs = new MyCustomStyleProperties(style);
	/// mcs.TheLocked = true;
	/// mcs.TheFont.Bold = true;
	/// 
	/// // design time code (both C# and VB)
	/// MyCustomStyleProperties myCustomStyleProperties1 = new MyCustomStyleProperties();
	/// myCustomStyleProperties1.TheLocked = true;
	/// myCustomStyleProperties1.TheFont.Bold = true;
	/// style.CustomProperties.Add(myCustomStyleProperties1);
	/// 
	/// // using ctor with indexer (C# only)
	/// (new MyCustomStyleProperties(grid[1,1])).TheLocked = true;
	/// (new MyCustomStyleProperties(grid[1,1])).TheFont.Bold = true;
	/// 
	/// // using ctor with exising style object (C# only)
	/// style.Text = "bla";
	/// new MyCustomStyleProperties(style).TheLocked = true;
	/// new MyCustomStyleProperties(style).TheFont.Bold = true;
	/// 
	/// // explicit case (C# only)
	/// ((MyCustomStyleProperties) style).TheLocked = true;
	/// ((MyCustomStyleProperties) style).TheFont.Bold = true;
	/// </code>
	/// <code lang="VB">
	/// Dim style As New GridStyleInfo()
	/// Dim grid As New GridControl()
	/// 
	/// ' using ctor with exising style object and caching the object (VB and C#)
	/// Dim mcs As New MyCustomStyleProperties(style)
	/// mcs.TheLocked = True
	/// mcs.TheFont.Bold = True
	/// 
	/// ' design time code (VB and C#)
	/// Dim myCustomStyleProperties1 As New MyCustomStyleProperties()
	/// myCustomStyleProperties1.TheLocked = True
	/// myCustomStyleProperties1.TheFont.Bold = True
	/// style.CustomProperties.Add(myCustomStyleProperties1)
	/// 
	/// ' with operator (Visual Basic only)
	/// With New MyCustomStyleProperties(style)
	///     .TheLocked = True
	///     .TheFont.Bold = True
	/// End With
	/// 
	/// ' with operator (Visual Basic only)
	/// With New MyCustomStyleProperties(grid(1, 1))
	///     .TheLocked = True
	///     .TheFont.Bold = True
	/// End With
	/// </code>
	/// </example>
	/// </remarks>
	public class MyCustomStyleProperties : GridStyleInfoCustomProperties
	{
		// static initialization of property descriptors
		static Type t = typeof(MyCustomStyleProperties);

		readonly static StyleInfoProperty LockedProperty = CreateStyleInfoProperty(t, "TheLocked");
		readonly static StyleInfoProperty TheFontProperty = CreateStyleInfoProperty(t, "TheFont"); 

		// default settings for all properties this object holds
		static MyCustomStyleProperties defaultObject;

		// initialize default settings for all properties in static ctor
		static MyCustomStyleProperties ()
		{
			// all properties must be initialized for the Default property
			defaultObject = new MyCustomStyleProperties(GridStyleInfo.Default);
			defaultObject.TheLocked = true;
			defaultObject.TheFont = GridFontInfo.Default;
		}
	
		/// <summary>
		/// Provides access to default values for this type
		/// </summary>
		public static MyCustomStyleProperties Default
		{
			get
			{
				return defaultObject;
			}
		}

		/// <summary>
		/// Force static ctor being called at least once
		/// </summary>
		public static void Initialize()
		{
		}

		// explicit cast from GridStyleInfo to MyCustomStyleProperties
		// (Note: this will only work for C#, Visual Basic does not support dynamic casts)

		/// <summary>
		/// Explicit cast from GridStyleInfo to this custom propety object
		/// </summary>
		/// <param name="style">The <see cref="GridStyleInfo"/> with the data we want get or change</param>
		/// <returns>A new custom properties object.</returns>
		public static explicit operator MyCustomStyleProperties(GridStyleInfo style)
		{
			return new MyCustomStyleProperties(style);
		}

		[System.Diagnostics.Conditional("Usage")]
		void Usage()
		{
			GridControl grid = new GridControl();
			GridStyleInfo style = new GridStyleInfo();

			// using ctor with exising style object and caching the object (both C# and VB)
			MyCustomStyleProperties mcs = new MyCustomStyleProperties(style);
			mcs.TheLocked = true;
			mcs.TheFont.Bold = true;

			// design time code (both C# and VB)
			MyCustomStyleProperties myCustomStyleProperties1 = new MyCustomStyleProperties();
			myCustomStyleProperties1.TheLocked = true;
			myCustomStyleProperties1.TheFont.Bold = true;
			style.CustomProperties.Add(myCustomStyleProperties1);
			
			// using ctor with indexer (C# only)
			(new MyCustomStyleProperties(grid[1,1])).TheLocked = true;
			(new MyCustomStyleProperties(grid[1,1])).TheFont.Bold = true;
			
			// using ctor with exising style object (C# only)
			style.Text = "bla";
			new MyCustomStyleProperties(style).TheLocked = true;
			new MyCustomStyleProperties(style).TheFont.Bold = true;

			// explicit case (C# only)
			((MyCustomStyleProperties) style).TheLocked = true;
			((MyCustomStyleProperties) style).TheFont.Bold = true;
		}

		/// <summary>
		/// Initializes a MyCustomStyleProperties object with a style object that holds all data 
		/// </summary>
		/// <param name="style">The <see cref="GridStyleInfo"/> with the data we want get or change</param>
		public MyCustomStyleProperties(GridStyleInfo style)
			: base(style)
		{
		}

		/// <summary>
		/// Initializes a MyCustomStyleProperties object with an empty style object. Design
		/// time environment will use this ctor and later copy the values to a style object
		/// by calling style.CustomProperties.Add(otherCustomStyleProperties1)
		/// </summary>
		public MyCustomStyleProperties()
			: base()
		{
		}

		/// <summary>
		/// Gets or sets TheLocked state
		/// </summary>
		[
		Description("Specifies if ..."),
		Browsable(true),
		Category("StyleCategoryBehavior")
		]
		public bool TheLocked
		{
			get 
			{
				return (bool) style.GetValue(LockedProperty);
			}
			set 
			{
				TraceUtil.TraceCurrentMethodInfo(value, LockedProperty.ComponentType.FullName);
				style.SetValue(LockedProperty, value);
			}
		}
		/// <summary>
		/// Resets TheLocked state
		/// </summary>
		public void ResetTheLocked()
		{
			style.ResetValue(LockedProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeTheLocked()
		{
			return style.HasValue(LockedProperty);
		}
		/// <summary>
		/// Gets if TheLocked state has been initialized for the current object.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasTheLocked
		{
			get
			{
				return style.HasValue(LockedProperty);
			}
		}

		/// <summary>
		/// Gets or sets TheFont state. TheFont is itsself a expandable object
		/// with several properties that can be set individually and participate
		/// in style inheritance mechanism.
		/// </summary>
		[
		Description("The font for drawing text."),
		Browsable(true),
		DesignerSerializationVisibility(DesignerSerializationVisibility.Content),
		Category("StyleCategoryAppearance")
		]
		public GridFontInfo TheFont
		{
			get 
			{
				return (GridFontInfo) style.GetValue(TheFontProperty);
			}
			set 
			{
				style.SetValue(TheFontProperty, value);
			}
		}

		/// <summary>
		/// Resets TheFont state.
		/// </summary>
		public void ResetTheFont()
		{
			style.ResetValue(TheFontProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeTheFont()
		{
			return style.HasValue(TheFontProperty);
		}
		/// <summary>
		/// Determines if TheFont state has been initialized for the current object.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasTheFont
		{
			get
			{
				return style.HasValue(TheFontProperty);
			}
		}

	}

}
