using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Runtime.Serialization;
using System.Runtime.InteropServices;

using System.Diagnostics;
using System.Globalization;

using Syncfusion.Diagnostics;
using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Drawing;
using Syncfusion.Styles;
using Syncfusion.Windows.Forms.Tools;

namespace MaskEditCells
{

	public class GridMaskEditCellModel : GridStaticCellModel
	{
		private MaskedEditBox maskEditBox = new MaskedEditBox();

		protected GridMaskEditCellModel(SerializationInfo info, StreamingContext context)
			: base(info, context)
		{
			// force static ctor of GridMaskEditStyleProperties being called at least once
			GridMaskEditStyleProperties.Initialize();
		}

		public GridMaskEditCellModel(GridModel grid)
			: base(grid)
		{
			AllowFloating = false;
		}
	
		public override GridCellRendererBase CreateRenderer(GridControlBase control)
		{
			return new GridMaskEditCellRenderer(control, this);
		}

		public override string GetFormattedText(GridStyleInfo style, object value, int textInfo)
		{
			InitMaskedEditProperties(this.maskEditBox, style);
			return maskEditBox.FormattedText;
		}

		public static void InitMaskedEditProperties(MaskedEditBox mb, GridStyleInfo style)
		{
			GridMaskEditStyleProperties mcs = new GridMaskEditStyleProperties(style);
			GridMaskEditInfo mi = mcs.MaskEdit;

			mb.BeginInit();

			CultureInfo ci = style.CultureInfo;
			if(ci == null)
				ci = CultureInfo.CurrentCulture;
			mb.Culture = ci;
			// style.HorizontalAlignment ?
			// style.VerticalAlignment ?
			// style.TextMargins ?
			// style.ReadOnly ?

			mb.AllowPrompt = mi.AllowPrompt;
			mb.ClipMode = mi.ClipMode;
			mb.DateSeparator = mi.DateSeparator;
			mb.DateTimeFormatInfoObject = mi.DateTimeFormatInfoObject;
			mb.DecimalSeparator = mi.DecimalSeparator;
			mb.Mask = mi.Mask;
			mb.MaxValue = mi.MaxValue;
			mb.MinValue = mi.MinValue;
			mb.NumberFormatInfoObject = mi.NumberFormatInfoObject;
			mb.PaddingCharacter = mi.PaddingCharacter;
			mb.PassivePromptCharacter = mi.PassivePromptCharacter;
			mb.PromptCharacter = mi.PromptCharacter;
			mb.SpecialCultureValue = mi.SpecialCultureValue;
			mb.ThousandSeparator = mi.ThousandSeparator;
			mb.TimeSeparator = mi.TimeSeparator;
			mb.UsageMode = mi.UsageMode;
			mb.UseLocaleDefault = mi.UseLocaleDefault;
			mb.UseUserOverride = mi.UseUserOverride;
			mb.MaxLength = style.MaxLength;
			mb.EndInit();
			mb.Text = style.Text;
		}
	}

	
	public class GridMaskEditCellRenderer: GridStaticCellRenderer
	{
		private MaskedEditBox focusControl;
		
		public GridMaskEditCellRenderer(GridControlBase grid, GridCellModelBase cellModel)
			: base(grid, cellModel)
		{
			this.SupportsFocusControl = true;
			focusControl = new MaskedEditBox();
			FixControlParent(focusControl);
			focusControl.ValidationError += new ValidationErrorEventHandler(FocusControlValidationError);
			focusControl.TextChanged += new EventHandler(FocusControlTextChanged);
		}

		void FixControlParent(Control control)
		{
			if (control.Parent != Grid || !control.Visible)
			{
				control.Location = new Point(-1000, -1000);
				control.CausesValidation = false;
				control.Anchor = AnchorStyles.None;
				control.Dock = DockStyle.None;
				control.Parent = Grid;
				control.Visible = true;
				SetControl(control);
			}
		}

		void FocusControlTextChanged(object sender, EventArgs e)
		{
			if (this.NotifyCurrentCellChanging())
			{
				this.NotifyCurrentCellChanged();
			}
		}

		protected override void OnDraw(System.Drawing.Graphics g, System.Drawing.Rectangle clientRectangle, int rowIndex, int colIndex, Syncfusion.Windows.Forms.Grid.GridStyleInfo style)
		{
			if (this.ShouldDrawFocused(rowIndex, colIndex))
			{
				if (this.focusControl != null)
				{
					clientRectangle.Inflate(-1, -1);

					// Set size
					focusControl.Size = clientRectangle.Size;
					focusControl.Location = clientRectangle.Location;
					if (!focusControl.ContainsFocus)
						focusControl.Focus();
				}
			}
			else
			{
				// will call GridMaskEditCellModel.GetFormattedText
				base.OnDraw(g, clientRectangle, rowIndex, colIndex, style);
			}
		}

		protected /*internal*/ override bool OnSaveChanges()
		{
			TraceUtil.TraceCurrentMethodInfo(this.focusControl.Text);
			this.Grid.Model[RowIndex, ColIndex].CellValue = this.focusControl.Text;
			return true;
		}

		private void CallValidate(Control control)
		{
			// Validate is a private method - using Reflection lets us call it anyway.
			System.Reflection.MethodInfo mInfo = focusControl.GetType().GetMethod("Validate", 
				System.Reflection.BindingFlags.Instance | 
				System.Reflection.BindingFlags.InvokeMethod | 
				System.Reflection.BindingFlags.NonPublic);
			if(mInfo != null)
			{
				mInfo.Invoke(control, new object[]{true});
			}
		}

		protected /*internal*/ override bool OnValidate()
		{
			invalidText = null;
			CallValidate(focusControl);
			if (invalidText != null)
			{
				CurrentCell.ErrorMessage = "Inalid Text: " + invalidText;
				return false;
			}
			return base.OnValidate();
		}

		string invalidText = null;

		void FocusControlValidationError(object sender, ValidationErrorArgs e)
		{
			invalidText = e.InvalidText;
		}

		protected override void OnInitialize(int rowIndex, int colIndex)
		{
			// Immeditaly switch into editing mode when cell is initialized.
			GridStyleInfo style = Grid.Model[rowIndex, colIndex];
			GridMaskEditCellModel.InitMaskedEditProperties(this.focusControl, style);
			focusControl.BeginInit();
			focusControl.BorderStyle = BorderStyle.None;
			//focusControl.BackColor = style.Interior.BackColor;
			focusControl.ForeColor = style.TextColor;
			focusControl.Font = style.GdipFont;
			focusControl.BackColor = Color.FromArgb(255, Grid.GetBackColor(style.Interior.BackColor));
			focusControl.EndInit();
			CurrentCell.BeginEdit();
			base.OnInitialize(rowIndex, colIndex);
		}

		protected override void OnActivated()
		{
			// Select all text when activated
			this.focusControl.SelectAll();
			base.OnActivated();
		}

		// Mouse hit
		/// <override/>
		protected override void OnClick(int rowIndex, int colIndex, MouseEventArgs e)
		{
			if (this.Grid.CurrentCell.HasCurrentCellAt(rowIndex, colIndex))
			{
				// Activate textbox and show caret 
				GridCellLayout layout = GetCellLayout(rowIndex, colIndex, Grid.Model[rowIndex, colIndex]);
				bool clickOnCell = layout.ClientRectangle.Contains(new Point(e.X, e.Y));
				TraceUtil.TraceCurrentMethodInfo(rowIndex, colIndex, new Point(e.X, e.Y), clickOnCell, layout.ClientRectangle);

				bool beginEdit = focusControl != null;

				if (beginEdit)
				{
					CurrentCell.BeginEdit();
					// Fake a mouse click.
					if (CurrentCell.HasControlFocus && e.Button == MouseButtons.Left)
					{
						focusControl.Update();
						Point loc = layout.ClientRectangle.Location;
						Point p = new Point(e.X-loc.X, e.Y-loc.Y);
						ActiveXSnapshot.FakeLeftMouseClick(focusControl, p);
					}
				}
			}
		
			base.OnClick(rowIndex, colIndex, e);
		}
	}

	public class GridMaskEditStyleProperties : GridStyleInfoCustomProperties
	{
		// static initialization of property descriptors
		static Type t = typeof(GridMaskEditStyleProperties);

		readonly static StyleInfoProperty MaskEditProperty = CreateStyleInfoProperty(t, "MaskEdit"); 

		// default settings for all properties this object holds
		static GridMaskEditStyleProperties defaultObject;

		// initialize default settings for all properties in static ctor
		static GridMaskEditStyleProperties ()
		{
			// all properties must be initialized for the Default property
			defaultObject = new GridMaskEditStyleProperties(GridStyleInfo.Default);
			defaultObject.MaskEdit = GridMaskEditInfo.Default;
		}
	
		/// <summary>
		/// Provides access to default values for this type
		/// </summary>
		public static GridMaskEditStyleProperties Default
		{
			get
			{
				return defaultObject;
			}
		}

		/// <summary>
		/// Force static ctor being called at least once
		/// </summary>
		public static void Initialize()
		{
		}

		// explicit cast from GridStyleInfo to GridMaskEditStyleProperties
		// (Note: this will only work for C#, Visual Basic does not support dynamic casts)

		/// <summary>
		/// Explicit cast from GridStyleInfo to this custom propety object
		/// </summary>
		/// <param name="style">The <see cref="GridStyleInfo"/> with the data we want get or change</param>
		/// <returns>A new custom properties object.</returns>
		public static explicit operator GridMaskEditStyleProperties(GridStyleInfo style)
		{
			return new GridMaskEditStyleProperties(style);
		}

		[System.Diagnostics.Conditional("Usage")]
		void Usage()
		{
			GridControl grid = new GridControl();
			GridStyleInfo style = new GridStyleInfo();

			// using ctor with exising style object and caching the object (both C# and VB)
			GridMaskEditStyleProperties mcs = new GridMaskEditStyleProperties(style);
			mcs.MaskEdit.AllowPrompt = true;

			// design time code (both C# and VB)
			GridMaskEditStyleProperties myCustomStyleProperties1 = new GridMaskEditStyleProperties();
			myCustomStyleProperties1.MaskEdit.AllowPrompt = true;
			style.CustomProperties.Add(myCustomStyleProperties1);
			
			// using ctor with indexer (C# only)
			(new GridMaskEditStyleProperties(grid[1,1])).MaskEdit.AllowPrompt = true;
			
			// using ctor with exising style object (C# only)
			style.Text = "bla";
			new GridMaskEditStyleProperties(style).MaskEdit.AllowPrompt = true;

			// explicit case (C# only)
			((GridMaskEditStyleProperties) style).MaskEdit.AllowPrompt = true;
		}

		/// <summary>
		/// Initializes a GridMaskEditStyleProperties object with a style object that holds all data 
		/// </summary>
		/// <param name="style">The <see cref="GridStyleInfo"/> with the data we want get or change</param>
		public GridMaskEditStyleProperties(GridStyleInfo style)
			: base(style)
		{
		}

		/// <summary>
		/// Initializes a GridMaskEditStyleProperties object with an empty style object. Design
		/// time environment will use this ctor and later copy the values to a style object
		/// by calling style.CustomProperties.Add(otherCustomStyleProperties1)
		/// </summary>
		public GridMaskEditStyleProperties()
			: base()
		{
		}

		/// <summary>
		/// Gets or sets MaskEdit state. MaskEdit is itsself a expandable object
		/// with several properties that can be set individually and participate
		/// in style inheritance mechanism.
		/// </summary>
		[
		Description("MaskEdit state."),
		Browsable(true),
		DesignerSerializationVisibility(DesignerSerializationVisibility.Content),
		Category("Custom")
		]
		public GridMaskEditInfo MaskEdit
		{
			get 
			{
				return (GridMaskEditInfo) style.GetValue(MaskEditProperty);
			}
			set 
			{
				style.SetValue(MaskEditProperty, value);
			}
		}

		/// <summary>
		/// Resets MaskEdit state.
		/// </summary>
		public void ResetMaskEdit()
		{
			style.ResetValue(MaskEditProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeMaskEdit()
		{
			return style.HasValue(MaskEditProperty);
		}
		/// <summary>
		/// Determines if MaskEdit state has been initialized for the current object.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasMaskEdit
		{
			get
			{
				return style.HasValue(MaskEditProperty);
			}
		}

	}


	/// <summary>
	/// Implements the data store for the <see cref="GridMaskEditInfo"/> object.
	/// </summary>
	/// <seealso cref="StyleInfoStore"/>
	[
	Serializable,
	StaticDataField("sd")
	]
	public class GridMaskEditInfoStore: StyleInfoStore
	{
		static StaticData sd = new StaticData(typeof(GridMaskEditInfoStore), typeof(GridMaskEditInfo), true);
		internal static StyleInfoProperty AllowPromptProperty = sd.CreateStyleInfoProperty(typeof(bool), "AllowPrompt"); 
		internal static StyleInfoProperty ClipModeProperty = sd.CreateStyleInfoProperty(typeof(ClipModes), "ClipMode"); 
		internal static StyleInfoProperty DateSeparatorProperty = sd.CreateStyleInfoProperty(typeof(char), "DateSeparator"); 
		internal static StyleInfoProperty DateTimeFormatInfoObjectProperty = sd.CreateStyleInfoProperty(typeof(DateTimeFormatInfo), "DateTimeFormatInfoObject"); 
		internal static StyleInfoProperty DecimalSeparatorProperty = sd.CreateStyleInfoProperty(typeof(char), "DecimalSeparator"); 
		internal static StyleInfoProperty MaskProperty = sd.CreateStyleInfoProperty(typeof(string), "Mask"); 
		internal static StyleInfoProperty MaxValueProperty = sd.CreateStyleInfoProperty(typeof(decimal), "MaxValue"); 
		internal static StyleInfoProperty MinValueProperty = sd.CreateStyleInfoProperty(typeof(decimal), "MinValue"); 
		internal static StyleInfoProperty NumberFormatInfoObjectProperty = sd.CreateStyleInfoProperty(typeof(NumberFormatInfo), "NumberFormatInfoObject"); 
		internal static StyleInfoProperty PaddingCharacterProperty = sd.CreateStyleInfoProperty(typeof(char), "PaddingCharacter"); 
		internal static StyleInfoProperty PassivePromptCharacterProperty = sd.CreateStyleInfoProperty(typeof(char), "PassivePromptCharacter"); 
		internal static StyleInfoProperty PromptCharacterProperty = sd.CreateStyleInfoProperty(typeof(char), "PromptCharacter"); 
		internal static StyleInfoProperty SpecialCultureValueProperty = sd.CreateStyleInfoProperty(typeof(SpecialCultureValues), "SpecialCultureValue"); 
		internal static StyleInfoProperty ThousandSeparatorProperty = sd.CreateStyleInfoProperty(typeof(char), "ThousandSeparator"); 
		internal static StyleInfoProperty TimeSeparatorProperty = sd.CreateStyleInfoProperty(typeof(char), "TimeSeparator"); 
		internal static StyleInfoProperty UsageModeProperty = sd.CreateStyleInfoProperty(typeof(MaskedUsageMode), "UsageMode"); 
		internal static StyleInfoProperty UseLocaleDefaultProperty = sd.CreateStyleInfoProperty(typeof(char), "UseLocaleDefault"); 
		internal static StyleInfoProperty UseUserOverrideProperty = sd.CreateStyleInfoProperty(typeof(char), "UseUserOverride"); 

		/// <override/>
		protected override StaticData StaticDataStore
		{
			get { return sd; }
		}

		/// <overload>
		/// Initializes a new <see cref="GridMaskEditInfoStore"/> object.
		/// </overload>
		/// <summary>
		/// Initializes a new empty <see cref="GridMaskEditInfoStore"/>
		/// </summary>
		public GridMaskEditInfoStore()
		{
		}

		/// <summary>
		/// Initializes a new <see cref="GridMaskEditInfoStore"/> from a serialization stream.
		/// </summary>
		/// <param name="info">An object that holds all the data needed to serialize or deserialize this instance.</param>
		/// <param name="context">Describes the source and destination of the serialized stream specified by info. </param>
		private GridMaskEditInfoStore(SerializationInfo info, StreamingContext context)
			: base(info, context)
		{
			//TraceUtil.TraceCurrentMethodInfoIf(Switches.Serialization.TraceVerbose, info.FullTypeName, info.MemberCount);
		}
			
		// Base class implementation of this method calls Activator.CreateInstance to achieve the same result.
		// I assume calling new directly is more efficient. Otherwise this override is obsolete.
		
		/// <override/>
		public override object Clone()
		{
			StyleInfoStore target = new GridMaskEditInfoStore();
			CopyTo(target);
			return target;
		}
	}
	
	/// <summary>
	/// Provides a <see cref="StyleInfoSubObjectBase"/> object for masked edit properties in a cell. 
	/// <para/>Each property in this sub object can be configured individually. Properties that
	/// have not been initialized will inherit default values from a base style.
	/// </summary>
	public class GridMaskEditInfo: StyleInfoSubObjectBase
	{
		// Static Fields
		private static GridMaskEditInfo defaultMaskEditInfo;

		internal static object CreateObject(StyleInfoSubObjectIdentity identity, object store)
		{
			if (store != null)
				return new GridMaskEditInfo(identity, store as GridMaskEditInfoStore);
			return new GridMaskEditInfo(identity);
		}


		// Constructors

		/// <summary>
		/// Initializes a new empty <see cref="GridMaskEditInfo"/> object.
		/// </summary>
		[DebuggerStepThrough()] public GridMaskEditInfo()
			: base(new GridMaskEditInfoStore())
		{
		}

		/// <summary>
		/// Initalizes a new <see cref="GridMaskEditInfo"/>  object and associates it with an existing <see cref="GridStyleInfoSubObjectIdentity"/>.
		/// </summary>
		/// <param name="identity">A <see cref="GridStyleInfoSubObjectIdentity"/> that holds the indentity for this <see cref="GridMaskEditInfo"/>.
		/// </param>
		[DebuggerStepThrough()] public GridMaskEditInfo(StyleInfoSubObjectIdentity identity)
			: base(identity, new GridMaskEditInfoStore())
		{
		}

		/// <summary>
		/// Initalizes a new <see cref="GridMaskEditInfo"/>  object and associates it with an existing <see cref="GridStyleInfoSubObjectIdentity"/>.
		/// </summary>
		/// <param name="identity">A <see cref="GridStyleInfoSubObjectIdentity"/> that holds the indentity for this <see cref="GridMaskEditInfo"/>.</param>
		/// <param name="store">A <see cref="GridMaskEditInfoStore"/> that holds data for this <see cref="GridMaskEditInfo"/>.
		/// All changes in this style object will saved in the <see cref="GridMaskEditInfoStore"/> object.</param>
		[DebuggerStepThrough()] public GridMaskEditInfo(StyleInfoSubObjectIdentity identity, GridMaskEditInfoStore store)
			: base(identity, store)
		{
		}

		// Base class implementation of this method calls Activator.CreateInstance to achieve the same result.
		// I assume calling new directly is more efficient. Otherwise this override is obsolete.
		
		/// <override/>
		[DebuggerStepThrough()] public override IStyleInfoSubObject MakeCopy(StyleInfoBase newOwner, StyleInfoProperty sip)
		{
			return new GridMaskEditInfo(newOwner.CreateSubObjectIdentity(sip), (GridMaskEditInfoStore) Store.Clone());
		}

		// Default
		/// <summary>
		/// Returns a default <see cref="GridMaskEditInfo"/> to be used with a default style.
		/// </summary>
		/// <remarks>
		/// The <see cref="GridStyleInfo.Default"/> of the <see cref="GridStyleInfo"/> class
		/// will return the validation info that this method generates through its
		/// overriden version of <see cref="GetDefaultStyle"/>.
		/// <para/>
		/// Default settings are: <para/>
		/// <list type="table">
		/// <listheader><term>Property</term><description>Value</description></listheader>
		/// <item><term><see cref="NumberRequired"/></term><description>false</description></item>
		/// </list>
		///  </remarks>
		public static GridMaskEditInfo Default
		{
			[DebuggerStepThrough()] 
			get
			{
				if (defaultMaskEditInfo == null)
				{
					defaultMaskEditInfo = new GridMaskEditInfo();
					
					// retrive default values from an empty masked edit box.
					MaskedEditBox eb = new MaskedEditBox();
					defaultMaskEditInfo.AllowPrompt = eb.AllowPrompt;
					defaultMaskEditInfo.ClipMode = eb.ClipMode;
					defaultMaskEditInfo.DateSeparator = eb.DateSeparator;
					defaultMaskEditInfo.DateTimeFormatInfoObject = eb.DateTimeFormatInfoObject;
					defaultMaskEditInfo.DecimalSeparator = eb.DecimalSeparator;
					defaultMaskEditInfo.Mask = eb.Mask;
					defaultMaskEditInfo.MaxValue = eb.MaxValue;
					defaultMaskEditInfo.MinValue = eb.MinValue;
					defaultMaskEditInfo.NumberFormatInfoObject = eb.NumberFormatInfoObject;
					defaultMaskEditInfo.PaddingCharacter = eb.PaddingCharacter;
					defaultMaskEditInfo.PassivePromptCharacter = eb.PassivePromptCharacter;
					defaultMaskEditInfo.PromptCharacter = eb.PromptCharacter;
					defaultMaskEditInfo.SpecialCultureValue = eb.SpecialCultureValue;
					defaultMaskEditInfo.ThousandSeparator = eb.ThousandSeparator;
					defaultMaskEditInfo.TimeSeparator = eb.TimeSeparator;
					defaultMaskEditInfo.UsageMode = eb.UsageMode;
					defaultMaskEditInfo.UseLocaleDefault = eb.UseLocaleDefault;
					defaultMaskEditInfo.UseUserOverride = eb.UseUserOverride;
				}

				return defaultMaskEditInfo;
			}
		}

		/// <summary>
		/// Returns <see cref="GridMaskEditInfo.Default"/>
		/// </summary>
		/// <returns>A <see cref="GridMaskEditInfo"/> object with default values.</returns>
		protected override StyleInfoBase GetDefaultStyle()
		{
			return Default;
		}
		
		// Properties
		#region AllowPrompt
		/// <summary>
		/// This property specifies if the prompt character can be allowed to be entered as a input character.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public bool AllowPrompt
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (bool) GetValue(GridMaskEditInfoStore.AllowPromptProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.AllowPromptProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="AllowPrompt"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetAllowPrompt()
		{
			ResetValue(GridMaskEditInfoStore.AllowPromptProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeAllowPrompt()
		{
			return HasValue(GridMaskEditInfoStore.AllowPromptProperty);
		}
		/// <summary>
		/// Checks if <see cref="AllowPrompt"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasAllowPrompt
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.AllowPromptProperty);
			}
		}
		GridMaskEditInfo SetAllowPrompt(bool value)
		{
			AllowPrompt = value;
			return this;
		}
		#endregion

		#region ClipMode
		/// <summary>
		/// Specifies the format of the text that will be returned by the MaskedEditBox control. The nature of the formatting is set the the <see cref="ClipModes"/> type.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public ClipModes ClipMode
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (ClipModes) GetValue(GridMaskEditInfoStore.ClipModeProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.ClipModeProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="ClipMode"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetClipMode()
		{
			ResetValue(GridMaskEditInfoStore.ClipModeProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeClipMode()
		{
			return HasValue(GridMaskEditInfoStore.ClipModeProperty);
		}
		/// <summary>
		/// Checks if <see cref="ClipMode"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasClipMode
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.ClipModeProperty);
			}
		}
		GridMaskEditInfo SetClipMode(ClipModes value)
		{
			ClipMode = value;
			return this;
		}
		#endregion

		#region DateSeparator
		/// <summary>
		/// The character to use when a date separator position is specified.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public char DateSeparator
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (char) GetValue(GridMaskEditInfoStore.DateSeparatorProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.DateSeparatorProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="DateSeparator"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetDateSeparator()
		{
			ResetValue(GridMaskEditInfoStore.DateSeparatorProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeDateSeparator()
		{
			return HasValue(GridMaskEditInfoStore.DateSeparatorProperty);
		}
		/// <summary>
		/// Checks if <see cref="DateSeparator"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasDateSeparator
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.DateSeparatorProperty);
			}
		}
		GridMaskEditInfo SetDateSeparator(char value)
		{
			DateSeparator = value;
			return this;
		}
		#endregion

		#region DateTimeFormatInfoObject
		/// <summary>
		/// The <see cref="System.Globalization.DateTimeFormatInfo"/> provides the necessary globalization information for the properties that rely on the datetime settings.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public DateTimeFormatInfo DateTimeFormatInfoObject
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (DateTimeFormatInfo) GetValue(GridMaskEditInfoStore.DateTimeFormatInfoObjectProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.DateTimeFormatInfoObjectProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="DateTimeFormatInfoObject"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetDateTimeFormatInfoObject()
		{
			ResetValue(GridMaskEditInfoStore.DateTimeFormatInfoObjectProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeDateTimeFormatInfoObject()
		{
			return HasValue(GridMaskEditInfoStore.DateTimeFormatInfoObjectProperty);
		}
		/// <summary>
		/// Checks if <see cref="DateTimeFormatInfoObject"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasDateTimeFormatInfoObject
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.DateTimeFormatInfoObjectProperty);
			}
		}
		GridMaskEditInfo SetDateTimeFormatInfoObject(DateTimeFormatInfo value)
		{
			DateTimeFormatInfoObject = value;
			return this;
		}
		#endregion

		#region DecimalSeparator
		/// <summary>
		/// The character to use when a decimal seprator position is specified.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public char DecimalSeparator
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (char) GetValue(GridMaskEditInfoStore.DecimalSeparatorProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.DecimalSeparatorProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="DecimalSeparator"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetDecimalSeparator()
		{
			ResetValue(GridMaskEditInfoStore.DecimalSeparatorProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeDecimalSeparator()
		{
			return HasValue(GridMaskEditInfoStore.DecimalSeparatorProperty);
		}
		/// <summary>
		/// Checks if <see cref="DecimalSeparator"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasDecimalSeparator
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.DecimalSeparatorProperty);
			}
		}
		GridMaskEditInfo SetDecimalSeparator(char value)
		{
			DecimalSeparator = value;
			return this;
		}
		#endregion

		#region Mask
		/// <summary>
		/// Use this property to define the mask string for the MaskedEditBox control.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public string Mask
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (string) GetValue(GridMaskEditInfoStore.MaskProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.MaskProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="Mask"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetMask()
		{
			ResetValue(GridMaskEditInfoStore.MaskProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeMask()
		{
			return HasValue(GridMaskEditInfoStore.MaskProperty);
		}
		/// <summary>
		/// Checks if <see cref="Mask"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasMask
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.MaskProperty);
			}
		}
		GridMaskEditInfo SetMask(string value)
		{
			Mask = value;
			return this;
		}
		#endregion

		#region MaxValue
		/// <summary>
		/// The Maximum Value that can be set through the MaskedEditBox.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public decimal MaxValue
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (decimal) GetValue(GridMaskEditInfoStore.MaxValueProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.MaxValueProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="MaxValue"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetMaxValue()
		{
			ResetValue(GridMaskEditInfoStore.MaxValueProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeMaxValue()
		{
			return HasValue(GridMaskEditInfoStore.MaxValueProperty);
		}
		/// <summary>
		/// Checks if <see cref="MaxValue"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasMaxValue
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.MaxValueProperty);
			}
		}
		GridMaskEditInfo SetMaxValue(decimal value)
		{
			MaxValue = value;
			return this;
		}
		#endregion

		#region MinValue
		/// <summary>
		/// The Minimum Value that can be set through the MaskedEditBox.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public decimal MinValue
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (decimal) GetValue(GridMaskEditInfoStore.MinValueProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.MinValueProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="MinValue"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetMinValue()
		{
			ResetValue(GridMaskEditInfoStore.MinValueProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeMinValue()
		{
			return HasValue(GridMaskEditInfoStore.MinValueProperty);
		}
		/// <summary>
		/// Checks if <see cref="MinValue"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasMinValue
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.MinValueProperty);
			}
		}
		GridMaskEditInfo SetMinValue(decimal value)
		{
			MinValue = value;
			return this;
		}
		#endregion

		#region NumberFormatInfoObject
		/// <summary>
		/// The <see cref="System.Globalization.NumberFormatInfo"/> provides the necessary globalization information for the properties that rely on these settings.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public NumberFormatInfo NumberFormatInfoObject
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (NumberFormatInfo) GetValue(GridMaskEditInfoStore.NumberFormatInfoObjectProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.NumberFormatInfoObjectProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="NumberFormatInfoObject"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetNumberFormatInfoObject()
		{
			ResetValue(GridMaskEditInfoStore.NumberFormatInfoObjectProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeNumberFormatInfoObject()
		{
			return HasValue(GridMaskEditInfoStore.NumberFormatInfoObjectProperty);
		}
		/// <summary>
		/// Checks if <see cref="NumberFormatInfoObject"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasNumberFormatInfoObject
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.NumberFormatInfoObjectProperty);
			}
		}
		GridMaskEditInfo SetNumberFormatInfoObject(NumberFormatInfo value)
		{
			NumberFormatInfoObject = value;
			return this;
		}
		#endregion

		#region PaddingCharacter
		/// <summary>
		/// Specifies the character that will be used instead of mask characters when the mask position has not been filled.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public char PaddingCharacter
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (char) GetValue(GridMaskEditInfoStore.PaddingCharacterProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.PaddingCharacterProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="PaddingCharacter"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetPaddingCharacter()
		{
			ResetValue(GridMaskEditInfoStore.PaddingCharacterProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializePaddingCharacter()
		{
			return HasValue(GridMaskEditInfoStore.PaddingCharacterProperty);
		}
		/// <summary>
		/// Checks if <see cref="PaddingCharacter"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasPaddingCharacter
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.PaddingCharacterProperty);
			}
		}
		GridMaskEditInfo SetPaddingCharacter(char value)
		{
			PaddingCharacter = value;
			return this;
		}
		#endregion

		#region PassivePromptCharacter
		/// <summary>
		/// Specifies the character that will be used instead of mask characters when the mask position has not been filled (when the control does not have the focus).
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public char PassivePromptCharacter
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (char) GetValue(GridMaskEditInfoStore.PassivePromptCharacterProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.PassivePromptCharacterProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="PassivePromptCharacter"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetPassivePromptCharacter()
		{
			ResetValue(GridMaskEditInfoStore.PassivePromptCharacterProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializePassivePromptCharacter()
		{
			return HasValue(GridMaskEditInfoStore.PassivePromptCharacterProperty);
		}
		/// <summary>
		/// Checks if <see cref="PassivePromptCharacter"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasPassivePromptCharacter
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.PassivePromptCharacterProperty);
			}
		}
		GridMaskEditInfo SetPassivePromptCharacter(char value)
		{
			PassivePromptCharacter = value;
			return this;
		}
		#endregion

		#region PromptCharacter
		/// <summary>
		/// Specifies the character that will be used instead of mask characters when the mask position has not been filled.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public char PromptCharacter
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (char) GetValue(GridMaskEditInfoStore.PromptCharacterProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.PromptCharacterProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="PromptCharacter"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetPromptCharacter()
		{
			ResetValue(GridMaskEditInfoStore.PromptCharacterProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializePromptCharacter()
		{
			return HasValue(GridMaskEditInfoStore.PromptCharacterProperty);
		}
		/// <summary>
		/// Checks if <see cref="PromptCharacter"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasPromptCharacter
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.PromptCharacterProperty);
			}
		}
		GridMaskEditInfo SetPromptCharacter(char value)
		{
			PromptCharacter = value;
			return this;
		}
		#endregion

		#region SpecialCultureValue
		/// <summary>
		/// The mode for the cultures
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public SpecialCultureValues SpecialCultureValue
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (SpecialCultureValues) GetValue(GridMaskEditInfoStore.SpecialCultureValueProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.SpecialCultureValueProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="SpecialCultureValue"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetSpecialCultureValue()
		{
			ResetValue(GridMaskEditInfoStore.SpecialCultureValueProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeSpecialCultureValue()
		{
			return HasValue(GridMaskEditInfoStore.SpecialCultureValueProperty);
		}
		/// <summary>
		/// Checks if <see cref="SpecialCultureValue"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasSpecialCultureValue
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.SpecialCultureValueProperty);
			}
		}
		GridMaskEditInfo SetSpecialCultureValue(SpecialCultureValues value)
		{
			SpecialCultureValue = value;
			return this;
		}
		#endregion

		#region ThousandSeparator
		/// <summary>
		/// The character to use when a thousands separator position is specified.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public char ThousandSeparator
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (char) GetValue(GridMaskEditInfoStore.ThousandSeparatorProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.ThousandSeparatorProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="ThousandSeparator"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetThousandSeparator()
		{
			ResetValue(GridMaskEditInfoStore.ThousandSeparatorProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeThousandSeparator()
		{
			return HasValue(GridMaskEditInfoStore.ThousandSeparatorProperty);
		}
		/// <summary>
		/// Checks if <see cref="ThousandSeparator"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasThousandSeparator
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.ThousandSeparatorProperty);
			}
		}
		GridMaskEditInfo SetThousandSeparator(char value)
		{
			ThousandSeparator = value;
			return this;
		}
		#endregion

		#region TimeSeparator
		/// <summary>
		/// The character to use when a time separator position is specified.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public char TimeSeparator
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (char) GetValue(GridMaskEditInfoStore.TimeSeparatorProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.TimeSeparatorProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="TimeSeparator"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetTimeSeparator()
		{
			ResetValue(GridMaskEditInfoStore.TimeSeparatorProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeTimeSeparator()
		{
			return HasValue(GridMaskEditInfoStore.TimeSeparatorProperty);
		}
		/// <summary>
		/// Checks if <see cref="TimeSeparator"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasTimeSeparator
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.TimeSeparatorProperty);
			}
		}
		GridMaskEditInfo SetTimeSeparator(char value)
		{
			TimeSeparator = value;
			return this;
		}
		#endregion

		#region UsageMode
		/// <summary>
		/// Specifies the usage mode for the MaskedEditBox.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public MaskedUsageMode UsageMode
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (MaskedUsageMode) GetValue(GridMaskEditInfoStore.UsageModeProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.UsageModeProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="UsageMode"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetUsageMode()
		{
			ResetValue(GridMaskEditInfoStore.UsageModeProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeUsageMode()
		{
			return HasValue(GridMaskEditInfoStore.UsageModeProperty);
		}
		/// <summary>
		/// Checks if <see cref="UsageMode"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasUsageMode
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.UsageModeProperty);
			}
		}
		GridMaskEditInfo SetUsageMode(MaskedUsageMode value)
		{
			UsageMode = value;
			return this;
		}
		#endregion

		#region UseLocaleDefault
		/// <summary>
		/// Specify if the individual globalization property changes are to be ignored. If set to true the individual values will be ignored and the locale default will be used.
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public bool UseLocaleDefault
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (bool) GetValue(GridMaskEditInfoStore.UseLocaleDefaultProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.UseLocaleDefaultProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="UseLocaleDefault"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetUseLocaleDefault()
		{
			ResetValue(GridMaskEditInfoStore.UseLocaleDefaultProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeUseLocaleDefault()
		{
			return HasValue(GridMaskEditInfoStore.UseLocaleDefaultProperty);
		}
		/// <summary>
		/// Checks if <see cref="UseLocaleDefault"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasUseLocaleDefault
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.UseLocaleDefaultProperty);
			}
		}
		GridMaskEditInfo SetUseLocaleDefault(bool value)
		{
			UseLocaleDefault = value;
			return this;
		}
		#endregion

		#region UseUserOverride
		/// <summary>
		/// The UseUserOverride paramater for CultureInfo
		/// </summary>
		[
		Browsable(true),
		Category("StyleCategoryAppearance")
		]
		public bool UseUserOverride
		{
			[DebuggerStepThrough()] 
			get 
			{
				return (bool) GetValue(GridMaskEditInfoStore.UseUserOverrideProperty);
			}
			[DebuggerStepThrough()] 
			set 
			{
				SetValue(GridMaskEditInfoStore.UseUserOverrideProperty, value);
			}
		}
		/// <summary>
		/// Resets the <see cref="UseUserOverride"/> property.
		/// </summary>
		[DebuggerStepThrough()] public void ResetUseUserOverride()
		{
			ResetValue(GridMaskEditInfoStore.UseUserOverrideProperty);
		}
		[EditorBrowsableAttribute(EditorBrowsableState.Never)]
		private bool ShouldSerializeUseUserOverride()
		{
			return HasValue(GridMaskEditInfoStore.UseUserOverrideProperty);
		}
		/// <summary>
		/// Checks if <see cref="UseUserOverride"/> property is initialized.
		/// </summary>
		[Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public bool HasUseUserOverride
		{
			[DebuggerStepThrough()] 
			get
			{
				return HasValue(GridMaskEditInfoStore.UseUserOverrideProperty);
			}
		}
		GridMaskEditInfo SetUseUserOverride(bool value)
		{
			UseUserOverride = value;
			return this;
		}
		#endregion
	};
}
